==> agrosyst-web-0.4.1-sources.jar: fr/inra/agrosyst/web/actions/security/UsersUnactivate.java <==
package fr.inra.agrosyst.web.actions.security;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: UsersUnactivate.java 1026 2013-08-27 07:52:36Z echatellier $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.4.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/security/UsersUnactivate.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.Set;

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import fr.inra.agrosyst.api.services.users.UserService;
import fr.inra.agrosyst.web.actions.AbstractAgrosystAction;

/**
 * Désactivation multiple d'utilisateurs.
 *
 * @author Arnaud Thimel <thimel@codelutin.com>
 */
public class UsersUnactivate extends AbstractAgrosystAction {

    private static final long serialVersionUID = 5338924873719324729L;

    protected UserService userService;

    protected Set<String> userIds;

    protected boolean activate;

    public void setUserService(UserService userService) {
        this.userService = userService;
    }

    public void setUserIds(Set<String> userIds) {
        this.userIds = userIds;
    }

    public void setActivate(boolean activate) {
        this.activate = activate;
    }

    @Override
    @Action(results = {@Result(type = "redirectAction", params = {
            "namespace", "/security", "actionName", "users-list"})})
    public String execute() throws Exception {
        userService.unactivateUsers(userIds, activate);
        return SUCCESS;
    }

}

==> agrosyst-web-0.6.1-sources.jar: fr/inra/agrosyst/web/actions/security/UsersUnactivate.java <==
package fr.inra.agrosyst.web.actions.security;

/*
 * #%L
 * Agrosyst :: Web
 * $Id: UsersUnactivate.java 1585 2013-10-07 15:53:58Z athimel $
 * $HeadURL: https://forge.codelutin.com/svn/agrosyst/tags/agrosyst-0.6.1/agrosyst-web/src/main/java/fr/inra/agrosyst/web/actions/security/UsersUnactivate.java $
 * %%
 * Copyright (C) 2013 INRA
 * %%
 * INRA - Tous droits réservés
 * #L%
 */

import java.util.Set;

import org.apache.struts2.convention.annotation.Action;
import org.apache.struts2.convention.annotation.Result;

import fr.inra.agrosyst.api.services.users.UserService;
import fr.inra.agrosyst.web.actions.admin.AbstractAdminAction;

/**
 * Désactivation multiple d'utilisateurs.
 *
 * @author Arnaud Thimel <thimel@codelutin.com>
 */
public class UsersUnactivate extends AbstractAdminAction {

    private static final long serialVersionUID = 5338924873719324729L;

    protected UserService userService;

    protected Set<String> userIds;

    protected boolean activate;

    public void setUserService(UserService userService) {
        this.userService = userService;
    }

    public void setUserIds(Set<String> userIds) {
        this.userIds = userIds;
    }

    public void setActivate(boolean activate) {
        this.activate = activate;
    }

    @Override
    @Action(results = {@Result(type = "redirectAction", params = {
            "namespace", "/security", "actionName", "users-list"})})
    public String execute() throws Exception {
        checkIsAdmin();
        userService.unactivateUsers(userIds, activate);
        return SUCCESS;
    }

}
